@@ -14,8 +14,12 @@ def parse(hub, client: "botocore.client.BaseClient", service: str, operation: st
             "operation_model"
         ].input_shape.required_members
         for p, data in params.items():
+            # Unwrap TagSpecification and get tags
+            if "TagSpecifications" in p:
+                p = "tags"
+                data = data.member.members["Tags"]
             parameters[p] = hub.pop_create.aws.param.parse(
-                param=data, required=p in required_params
+                param=data, required=p in required_params, parsed_nested_params=[]
             )
     except AttributeError as e:
         hub.log.error(f"Error reading parameters for {service}.{operation}: {e}")
