@@ -21,14 +21,14 @@ async def get(
         name (str):
             The name of the Idem state.
 
-        resource_id (str, optional):
+        resource_id (str, Optional):
             Snapshot ID of the snapshot.
 
-        filters (list, optional):
+        filters (list, Optional):
             One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
             https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_snapshots
 
-        tags (dict, optional):
+        tags (dict, Optional):
             The dict of tags to filter by in the format ``{tag-key: tag-value}`` . For example, to find all resources
             that have a tag with the key "Owner" and the value "TeamA" , specify ``{Owner: TeamA}``
 
@@ -97,11 +97,11 @@ async def list_(
         name(str):
             The name of the Idem state.
 
-        filters (list, optional):
+        filters (list, Optional):
             One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
             https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_snapshots
 
-        tags (dict, optional):
+        tags (dict, Optional):
             The dict of tags to filter by in the format ``{tag-key: tag-value}`` . For example, to find all resources
             that have a tag with the key "Owner" and the value "TeamA" , specify ``{Owner: TeamA}``
 
