@@ -16,10 +16,10 @@ async def get(
     Get a VPC resource from AWS. Supply one of the inputs as the filter.
 
     Args:
-        name(string): The name of the Idem state.
-        resource_id(string, optional): AWS VPC id to identify the resource.
-        default(bool, optional): Indicate whether the VPC is the default VPC.
-        filters(list, optional): One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
+        name(str): The name of the Idem state.
+        resource_id(str, Optional): AWS VPC id to identify the resource.
+        default(bool, Optional): Indicate whether the VPC is the default VPC.
+        filters(list, Optional): One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
          https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_vpcs
 
     """
@@ -67,9 +67,9 @@ async def list_(hub, ctx, name, filters: List = None, default: bool = None) -> D
     Use an un-managed VPC as a data-source. Supply one of the inputs as the filter.
 
     Args:
-        name(string): The name of the Idem state.
-        default(bool, optional): Indicate whether the VPC is the default VPC.
-        filters(list, optional): One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
+        name(str): The name of the Idem state.
+        default(bool, Optional): Indicate whether the VPC is the default VPC.
+        filters(list, Optional): One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
          https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_vpcs
 
     """
