@@ -6,9 +6,31 @@ __func_alias__ = {"list_": "list"}
 
 async def get(hub, ctx, name: str, resource_id: str) -> Dict:
     """Returns the S3 bucket.
+
     Args:
-        name(str): The name of the Idem state.
-        resource_id(str): AWS S3 bucket name.
+        name(str):
+            The name of the Idem state.
+
+        resource_id(str):
+            AWS S3 bucket name.
+
+    Examples:
+        Calling from the CLI:
+
+        .. code-block:: bash
+
+            $ idem exec aws.s3.bucket.get name="bucket-name" resource_id="bucket-id"
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            get_a_bucket:
+              exec.run:
+                - path: aws.s3.bucket.get
+                - kwargs:
+                   name: bucket-name
+                   resource_id: bucket-id
     """
     result = dict(comment=[], ret=None, result=True)
     resource = await hub.tool.boto3.resource.create(ctx, "s3", "Bucket", resource_id)
@@ -39,6 +61,23 @@ async def list_(
     Args:
         name(str):
             The name of the Idem state.
+
+    Examples:
+        Calling from the CLI:
+
+        .. code-block:: bash
+
+            $ idem exec aws.s3.bucket.list name="bucket-name"
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            buckets_list:
+              exec.run:
+                - path: aws.s3.bucket.list
+                - kwargs:
+                   name: bucket-name
     """
     result = dict(comment=[], ret=[], result=True)
     ret = await hub.exec.boto3.client.s3.list_buckets(ctx)
