@@ -1,3 +1,4 @@
+"""Exec functions for S3 bucket's acl."""
 from typing import Dict
 
 
@@ -5,8 +6,29 @@ async def get(hub, ctx, resource_id, name) -> Dict:
     """Returns the ACL policy for the S3 bucket.
 
     Args:
-        resource_id(str): AWS S3 bucket name.
-        name(str): The name of the Idem state.
+        resource_id(str):
+            AWS S3 bucket name.
+
+        name(str):
+            The name of the Idem state.
+
+    Examples:
+        Calling from the CLI:
+
+        .. code-block:: bash
+
+            $ idem exec aws.s3.bucket_acl.get name="bucket-acl-name" resource_id="bucket-acl-id"
+
+        Using in a state:
+
+        .. code-block:: yaml
+
+            get_a_bucket_acl:
+              exec.run:
+                - path: aws.s3.bucket_acl.get
+                - kwargs:
+                   name: bucket-acl-name
+                   resource_id: bucket-acl-id
     """
     result = dict(comment=[], ret=None, result=True)
 
