@@ -126,7 +126,7 @@ async def present(
         )
     ] = None,
 ) -> Dict[str, Any]:
-    r"""Manage SSL/TLS certificates for your AWS-based websites and applications.
+    """Manage SSL/TLS certificates for your AWS-based websites and applications.
 
     Imports a certificate into AWS Certificate Manager (ACM) to use with services that are integrated with ACM.
 
@@ -578,7 +578,7 @@ async def present(
 
 
 async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]:
-    r"""Deletes a certificate and its associated private key.
+    """Deletes a certificate and its associated private key.
 
     If this action succeeds, the certificate no longer appears in the list that can be displayed by calling the
     ListCertificates action or be retrieved by calling the GetCertificate action.
@@ -657,7 +657,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
+    """Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
     Returns detailed metadata about ACM certificates.
 
@@ -729,7 +729,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
 
 
 def is_pending(hub, ret):
-    r"""Reconciliation is_pending plugin for ACM certificates."""
+    """Reconciliation is_pending plugin for ACM certificates."""
     new_state = ret.get("new_state", None)
     resource_id = new_state.get("resource_id") if new_state else None
     status = None
