@@ -29,7 +29,7 @@ async def present(
         ],
     ) = None,
 ) -> Dict[str, Any]:
-    r"""Registers or updates a scalable target.
+    """Registers or updates a scalable target.
 
     A scalable target is a resource that Application Auto Scaling can scale
     out and scale in. Scalable targets are uniquely identified by the combination of resource ID, scalable
@@ -357,7 +357,7 @@ async def absent(
     scalable_dimension: str,
     resource_id: str = None,
 ) -> Dict[str, Any]:
-    r"""Deregisters an Application Auto Scaling scalable target when you have finished using it.
+    """Deregisters an Application Auto Scaling scalable target when you have finished using it.
 
     To see which resources have been registered, use DescribeScalableTargets.
     Deregistering a scalable target deletes the scaling policies and the scheduled actions that are associated with it.
@@ -526,7 +526,7 @@ async def absent(
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
+    """Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
     Gets information about the scalable targets in the specified namespace. You can filter the results using
     ResourceIds and ScalableDimension.
