@@ -233,7 +233,7 @@ async def present(
         ],
     ) = None,
 ) -> Dict[str, Any]:
-    r"""Creates or updates a scaling policy for an Auto Scaling group.
+    """Creates or updates a scaling policy for an Auto Scaling group.
 
     Scaling policies are used to scale an Auto Scaling group based on configurable metrics. If no policies are defined,
     the dynamic scaling and predictive scaling features are not used.
@@ -934,7 +934,7 @@ async def absent(
     auto_scaling_group_name: str,
     resource_id: str = None,
 ) -> Dict[str, Any]:
-    r"""Deletes the specified scaling policy.
+    """Deletes the specified scaling policy.
 
     Deleting either a step scaling policy or a simple scaling policy deletes the underlying alarm action, but does not
     delete the alarm, even if it no longer has an associated action.
@@ -1015,7 +1015,7 @@ async def absent(
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""Describes the AutoScaling scaling policies in the account and Region.
+    """Describes the AutoScaling scaling policies in the account and Region.
 
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
