@@ -9,7 +9,7 @@ async def get(hub, ctx, name) -> Dict[str, Any]:
     Details about the IAM user or role whose credentials are used to call the operation.
 
     Args:
-        name(string): An Idem name of the resource.
+        name(str): An Idem name of the resource.
 
     Request Syntax:
         [Idem-resource-state-name]:
@@ -31,10 +31,10 @@ async def get(hub, ctx, name) -> Dict[str, Any]:
           }
 
     Response Structure:
-        name(string): An Idem name of the resource.
-        user_id(string): The unique identifier of the calling entity.
-        account_id(string): AWS account ID number of the account that owns or contains the calling entity.
-        arn(string): AWS ARN associated with the calling entity.
+        name(str): An Idem name of the resource.
+        user_id(str): The unique identifier of the calling entity.
+        account_id(str): AWS account ID number of the account that owns or contains the calling entity.
+        arn(str): AWS ARN associated with the calling entity.
 
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
