@@ -15,7 +15,7 @@ async def present(
     tags: Dict[str, str] = None,
     retention_in_days: int = None,
 ) -> Dict[str, Any]:
-    r"""Creates a log group with the specified name.
+    """Creates a log group with the specified name.
 
     You can create up to 5000 log groups per account.
 
@@ -165,7 +165,7 @@ async def present(
 
 
 async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]:
-    r"""Deletes the specified cloudwatch log group.
+    """Deletes the specified cloudwatch log group.
 
     Args:
         name(str): An Idem name of the Log Group.
@@ -233,7 +233,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""Lists the AWS CloudWatch Log Groups.
+    """Lists the AWS CloudWatch Log Groups.
 
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
