@@ -13,7 +13,7 @@ async def present(
     policy_document: str,
     resource_id: str = None,
 ) -> Dict[str, Any]:
-    r"""Creates or updates a resource policy allowing other Amazon Web Services services to put log events to this account, such as Amazon Route 53.
+    """Creates or updates a resource policy allowing other Amazon Web Services services to put log events to this account, such as Amazon Route 53.
 
     An account can have up to 10 resource policies per Amazon Web Services Region.
 
@@ -128,7 +128,7 @@ async def present(
 
 
 async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]:
-    r"""Deletes a resource policy from this account.
+    """Deletes a resource policy from this account.
 
     This revokes the access of the identities in that policy to put log events to this account.
 
@@ -197,7 +197,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""Lists the resource policies in this account.
+    """Lists the resource policies in this account.
 
     Returns:
         Dict[str, Any]
