@@ -8,6 +8,14 @@ from typing import List
 
 __contracts__ = ["resource"]
 
+TREQ = {
+    "absent": {
+        "require": [
+            "aws.config.delivery_channel.present",
+        ],
+    },
+}
+
 
 async def present(
     hub,
@@ -22,7 +30,6 @@ async def present(
             ("resourceTypes", List[str], field(default=None)),
         ],
     ),
-    recording: bool = False,
     resource_id: str = None,
 ) -> Dict[str, Any]:
     """Creates a new configuration recorder to record the selected resource configurations.
@@ -71,9 +78,6 @@ async def present(
               For a list of valid resourceTypes values, see the resourceType Value column in Supported
               Amazon Web Services resource Types.
 
-        recording (bool, Optional):
-            Specifies recording status of the configuration recorder. Default is False.
-
         resource_id (str, Optional):
             The name of the recorder.
 
@@ -85,7 +89,6 @@ async def present(
               - name: 'string'
               - resource_id: 'string'
               - role_arn: 'string'
-              - recording: 'string'
               - recording_group: 'dict'
 
     Returns:
@@ -99,7 +102,6 @@ async def present(
                  - name: 'config_recorder'
                  - resource_id: 'config_recorder'
                  - role_arn: 'arn:aws:iam::012345678912:role/aws-service-role/config.amazonaws.com/AWSServiceRoleForConfig'
-                 - recording: true
                  - recording_group:
                     allSupported: false
                     includeGlobalResourceTypes: false
@@ -108,8 +110,7 @@ async def present(
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     before = None
-    resource_updated: bool = False
-    only_recording_status_changed: bool = False
+    resource_updated: bool = True
 
     if resource_id:
         resource = await hub.exec.boto3.client.config.describe_configuration_recorders(
@@ -124,26 +125,8 @@ async def present(
             before = resource["ret"]["ConfigurationRecorders"][0]
 
     if before:
-        before_recording_status = (
-            await hub.exec.boto3.client.config.describe_configuration_recorder_status(
-                ctx,
-                ConfigurationRecorderNames=[name],
-            )
-        )
-        if not before_recording_status["result"]:
-            result["comment"] = before_recording_status["comment"]
-            result["result"] = False
-            return result
-        before["recording"] = before_recording_status["ret"][
-            "ConfigurationRecordersStatus"
-        ][0]["recording"]
-
         resource_translated = await hub.tool.aws.config.conversion_utils.convert_raw_config_recorder_to_present(
-            ctx,
-            raw_resource=before,
-            recording=before_recording_status["ret"]["ConfigurationRecordersStatus"][0][
-                "recording"
-            ],
+            ctx, raw_resource=before
         )
         result["old_state"] = resource_translated
         resource_updated = await hub.tool.aws.config.config_utils.is_resource_updated(
@@ -151,13 +134,6 @@ async def present(
             role_arn=role_arn,
             recording_group=recording_group,
         )
-        if not resource_updated and resource_translated["recording"] == recording:
-            result["comment"] = (f"aws.config.config_recorder '{name}' already exists",)
-            result["new_state"] = copy.deepcopy(result["old_state"])
-            return result
-
-        if not resource_updated and resource_translated["recording"] != recording:
-            only_recording_status_changed = True
 
     if ctx.get("test", False):
         result["new_state"] = hub.tool.aws.test_state_utils.generate_test_state(
@@ -165,21 +141,15 @@ async def present(
             desired_state={
                 "name": name,
                 "role_arn": role_arn,
-                "recording": recording,
                 "resource_id": resource_id,
                 "recording_group": recording_group,
             },
         )
-        operation = (
-            "update"
-            if before
-            and (resource_updated or resource_translated["recording"] != recording)
-            else "create"
-        )
+        operation = "update" if before else "create"
         result["comment"] = (f"Would {operation} aws.config.config_recorder '{name}'",)
         return result
 
-    if not only_recording_status_changed:
+    if resource_updated:
         update_ret = await hub.exec.boto3.client.config.put_configuration_recorder(
             ctx=ctx,
             ConfigurationRecorder={
@@ -205,58 +175,13 @@ async def present(
         result[
             "new_state"
         ] = await hub.tool.aws.config.conversion_utils.convert_raw_config_recorder_to_present(
-            ctx,
-            raw_resource=after_ret["ret"]["ConfigurationRecorders"][0],
-            recording=None,
+            ctx, raw_resource=after_ret["ret"]["ConfigurationRecorders"][0]
         )
         operation = "Created" if not before else "Updated"
         result["comment"] = (f"{operation} aws.config.config_recorder '{name}'",)
     else:
+        result["comment"] = (f"aws.config.config_recorder '{name}' already exists",)
         result["new_state"] = copy.deepcopy(result["old_state"])
-
-    # If it is create recorder case and recording is True
-    #   OR
-    # If it is update recorder case and recording status is changed
-    if (not before and recording) or (before and recording != before["recording"]):
-        if recording:
-            recording_status_ret = (
-                await hub.exec.boto3.client.config.start_configuration_recorder(
-                    ctx=ctx, ConfigurationRecorderName=name
-                )
-            )
-        else:
-            recording_status_ret = (
-                await hub.exec.boto3.client.config.stop_configuration_recorder(
-                    ctx=ctx, ConfigurationRecorderName=name
-                )
-            )
-        if not recording_status_ret["result"]:
-            result["comment"] = recording_status_ret["comment"]
-            result["result"] = False
-            return result
-
-        after_recording_status_ret = (
-            await hub.exec.boto3.client.config.describe_configuration_recorder_status(
-                ctx,
-                ConfigurationRecorderNames=[name],
-            )
-        )
-        if not after_recording_status_ret["result"]:
-            result["comment"] = after_recording_status_ret["comment"]
-            result["result"] = False
-            return result
-        result["new_state"]["recording"] = after_recording_status_ret["ret"][
-            "ConfigurationRecordersStatus"
-        ][0]["recording"]
-        if only_recording_status_changed:
-            result["comment"] = hub.tool.aws.comment_utils.update_comment(
-                resource_type="aws.config.config_recorder", name=name
-            )
-    else:
-        if not before:
-            result["new_state"]["recording"] = False
-        else:
-            result["new_state"]["recording"] = before["recording"]
     return result
 
 
@@ -287,41 +212,30 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     before = None
-    if resource_id:
-        resource = await hub.exec.boto3.client.config.describe_configuration_recorders(
-            ctx,
-            ConfigurationRecorderNames=[name],
+    if not resource_id:
+        result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
+            resource_type="aws.config.config_recorder", name=name
         )
-        if not resource["result"]:
-            if "NoSuchConfigurationRecorderException" in str(resource["comment"]):
-                result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
-                    resource_type="aws.config.config_recorder", name=name
-                )
-                return result
-            result["comment"] = resource["comment"]
-            result["result"] = False
+        return result
+
+    resource = await hub.exec.boto3.client.config.describe_configuration_recorders(
+        ctx,
+        ConfigurationRecorderNames=[name],
+    )
+    if not resource["result"]:
+        if "NoSuchConfigurationRecorderException" in str(resource["comment"]):
+            result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
+                resource_type="aws.config.config_recorder", name=name
+            )
             return result
-        else:
-            before = resource["ret"]["ConfigurationRecorders"][0]
+        result["comment"] = resource["comment"]
+        result["result"] = False
+        return result
+    before = resource["ret"]["ConfigurationRecorders"][0]
 
     if before:
-        before_recording = (
-            await hub.exec.boto3.client.config.describe_configuration_recorder_status(
-                ctx,
-                ConfigurationRecorderNames=[name],
-            )
-        )
-        if not before_recording["result"]:
-            result["comment"] = before_recording["comment"]
-            result["result"] = False
-            return result
-
         translated_resource = await hub.tool.aws.config.conversion_utils.convert_raw_config_recorder_to_present(
-            ctx,
-            raw_resource=before,
-            recording=before_recording["ret"]["ConfigurationRecordersStatus"][0][
-                "recording"
-            ],
+            ctx, raw_resource=before
         )
         result["old_state"] = translated_resource
     else:
@@ -370,25 +284,9 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
 
     for resource in ret["ret"]["ConfigurationRecorders"]:
         name = resource["name"]
-        recording_status = (
-            await hub.exec.boto3.client.config.describe_configuration_recorder_status(
-                ctx,
-                ConfigurationRecorderNames=[name],
-            )
-        )
-        if not recording_status["result"]:
-            hub.log.warning(
-                f"Could not fetch configuration recorder '{name}' status with error {recording_status['comment']}"
-            )
-            continue
-
         recorder_name = f"{name}-config-recorder"
         translated_resource = await hub.tool.aws.config.conversion_utils.convert_raw_config_recorder_to_present(
-            ctx,
-            raw_resource=resource,
-            recording=recording_status["ret"]["ConfigurationRecordersStatus"][0][
-                "recording"
-            ],
+            ctx, raw_resource=resource
         )
         result[recorder_name] = {
             "aws.config.config_recorder.present": [
