@@ -1,3 +1,5 @@
+import base64
+import copy
 import datetime
 from dataclasses import field
 from dataclasses import make_dataclass
@@ -916,10 +918,14 @@ async def present(
         return result
 
     # If no attributes need modification, then return right away
+    desired_state = hub.states.aws.ec2.instance.pre_process_desired_state(
+        chunk=desired_state
+    )
+
     if all(
         current_state.get(attribute) == new_value
         for attribute, new_value in desired_state.items()
-        if new_value is not None
+        if attribute != "network_interfaces" and new_value is not None
     ):
         result["new_state"] = current_state
         return result
@@ -1046,3 +1052,12 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         }
 
     return result
+
+
+def pre_process_desired_state(hub, chunk):
+    desired_state = copy.deepcopy(chunk)
+    if desired_state.get("user_data"):
+        user_data = desired_state["user_data"]
+        desired_state["user_data"] = base64.b64encode(user_data.encode()).decode()
+
+    return desired_state
