@@ -348,7 +348,7 @@ async def search(
     vpc_id: str = None,
     tags: List[Dict[str, Any]] or Dict[str, Any] = None,
 ):
-    r"""
+    """
     Provides details about a specific Security Group as a data-source. Supply one of the inputs as the filter.
 
     Args:
@@ -404,7 +404,13 @@ async def search(
                       Value: sg-tag-value-2
 
 
+    This function has been deprecated.  Please use exec.run with aws.ec2.security_group.get or
+    aws.ec2.security_group.list instead.
     """
+    hub.log.warning(
+        f"aws.ec2.security_group.search '{name}' state has been deprecated. Please use exec.run with"
+        "aws.ec2.security_group.get or aws.ec2.security_group.list instead."
+    )
 
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     syntax_validation = hub.tool.aws.search_utils.search_filter_syntax_validation(
