@@ -662,7 +662,7 @@ async def present(
 
 
 async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]:
-    r"""
+    """
     Cancels one or more Spot Instance requests.
 
     Args:
@@ -762,10 +762,10 @@ async def search(hub, ctx, name: str, filters: List = None, resource_id: str = N
     Args:
         hub:
         ctx:
-        name(Text): The name of the Idem state.
-        resource_id(Text, optional): AWS VPC id to identify the resource.
-        filters(list, optional): One or more filters: for example, tag :<key>, tag-key.
-        A complete list of filters can be found at https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_instances
+        name(str): The name of the Idem state.
+        resource_id(str, Optional): AWS VPC id to identify the resource.
+        filters(list, Optional): One or more filters: for example, tag :<key>, tag-key.
+            A complete list of filters can be found at https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_instances
 
     Request Syntax:
         [Idem-state-name]:
@@ -782,7 +782,14 @@ async def search(hub, ctx, name: str, filters: List = None, resource_id: str = N
             my-unmanaged-spot_instance_request:
               aws.ec2.spot_instance_request.search:
                 - resource_id: value
+
+    This function has been deprecated.  Please use exec.run with aws.ec2.spot_instance_request.get or
+    aws.ec2.spot_instance_request.list instead.
     """
+    hub.log.warning(
+        f"aws.ec2.spot_instance_request.search '{name}' state has been deprecated. Please use exec.run with"
+        "aws.ec2.spot_instance_request.get or aws.ec2.spot_instance_request.list instead."
+    )
     result = dict(
         comment=[], old_state=ctx.old_state, new_state=None, name=name, result=True
     )
