@@ -117,42 +117,25 @@ async def present(
 
     before_ret = None
     if resource_id:
-        before_ret = await hub.exec.boto3.client.ecr.describe_repositories(
-            ctx, repositoryNames=[resource_id], registryId=registry_id
+        before_ret = await hub.exec.aws.ecr.repository.get(
+            ctx, name=name, resource_id=resource_id, registry_id=registry_id
         )
+
     if isinstance(tags, List):
         tags = hub.tool.aws.tag_utils.convert_tag_list_to_dict(tags)
 
     # Repositories cannot be updated after creation with the Amazon Web Service API,
     # only repository tags can be updated
-    if before_ret and before_ret["ret"].get("repositories"):  # resource present
+    if before_ret and before_ret["ret"]:  # resource present
         result["comment"] = (f"aws.ecr.repository '{name}' already exists",)
 
         updated = False
-        repository = before_ret["ret"].get("repositories")[0]
-
-        before_tags_ret = await hub.exec.boto3.client.ecr.list_tags_for_resource(
-            ctx, resourceArn=repository.get("repositoryArn")
-        )
-        if not before_tags_ret["result"]:
-            result["result"] = False
-            result["comment"] = result["comment"] + before_tags_ret["comment"]
-            return result
-
-        result[
-            "old_state"
-        ] = hub.tool.aws.ecr.conversion_utils.convert_raw_repository_to_present(
-            raw_resource=repository,
-            tags=before_tags_ret.get("ret").get("tags")
-            if before_tags_ret.get("result")
-            else None,
-            idem_resource_name=name,
-        )
+        result["old_state"] = copy.deepcopy(before_ret["ret"])
 
         if tags is not None and tags != result["old_state"].get("tags"):
             update_tags_ret = await hub.tool.aws.ecr.tag.update_tags(
                 ctx=ctx,
-                resource_arn=repository.get("repositoryArn"),
+                resource_arn=result["old_state"].get("repository_arn"),
                 old_tags=result["old_state"].get("tags"),
                 new_tags=tags,
             )
@@ -226,33 +209,11 @@ async def present(
         )
         resource_id = name
 
-    after_ret = await hub.exec.boto3.client.ecr.describe_repositories(
-        ctx, registryId=registry_id, repositoryNames=[resource_id]
+    new_state = await hub.exec.aws.ecr.repository.get(
+        ctx, name=name, resource_id=resource_id, registry_id=registry_id
     )
-    if not after_ret["result"]:
-        result["result"] = False
-        result["comment"] = after_ret["comment"]
-        return result
 
-    repository = after_ret["ret"].get("repositories")[0]
-
-    after_tags_ret = await hub.exec.boto3.client.ecr.list_tags_for_resource(
-        ctx, resourceArn=repository.get("repositoryArn")
-    )
-    if not after_tags_ret["result"]:
-        result["result"] = False
-        result["comment"] = after_tags_ret["comment"]
-        return result
-
-    result[
-        "new_state"
-    ] = hub.tool.aws.ecr.conversion_utils.convert_raw_repository_to_present(
-        raw_resource=repository,
-        tags=after_tags_ret.get("ret").get("tags")
-        if after_tags_ret.get("result")
-        else None,
-        idem_resource_name=name,
-    )
+    result["new_state"] = copy.deepcopy(new_state["ret"])
 
     return result
 
@@ -316,43 +277,37 @@ async def absent(
         )
         return result
 
-    before_ret = await hub.exec.boto3.client.ecr.describe_repositories(
-        ctx, repositoryNames=[resource_id], registryId=registry_id
+    before_ret = await hub.exec.aws.ecr.repository.get(
+        ctx, name=name, resource_id=resource_id, registry_id=registry_id
     )
+
+    # Case: Error
     if not before_ret["result"]:
+        result["result"] = False
+        result["comment"] = before_ret["comment"]
+        return result
+
+    # Case: No repository in the result
+    if not before_ret["ret"]:
         result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
             resource_type="aws.ecr.repository", name=name
         )
         return result
-
-    repository = before_ret["ret"].get("repositories")[0]
-
-    tags_ret = await hub.exec.boto3.client.ecr.list_tags_for_resource(
-        ctx, resourceArn=repository.get("repositoryArn")
-    )
-    if not tags_ret["result"]:
-        result["result"] = False
-        result["comment"] = tags_ret["comment"]
-        return result
-
-    result[
-        "old_state"
-    ] = hub.tool.aws.ecr.conversion_utils.convert_raw_repository_to_present(
-        raw_resource=repository,
-        tags=tags_ret.get("ret").get("tags") if tags_ret.get("result") else None,
-        idem_resource_name=name,
-    )
-
-    if ctx.get("test", False):
+    elif ctx.get("test", False):
+        # Case: --test context
+        result["old_state"] = before_ret["ret"]
         result["comment"] = hub.tool.aws.comment_utils.would_delete_comment(
             resource_type="aws.ecr.repository", name=name
         )
         return result
 
+    # Case: Found the old state
+    result["old_state"] = copy.deepcopy(before_ret["ret"])
     delete_ret = await hub.exec.boto3.client.ecr.delete_repository(
         ctx, repositoryName=resource_id, registryId=registry_id, force=force
     )
-    if not result["result"]:
+
+    if not delete_ret["result"]:
         result["result"] = False
         result["comment"] = delete_ret["comment"]
         return result
@@ -377,36 +332,17 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     """
     result = {}
 
-    describe_ret = await hub.exec.boto3.client.ecr.describe_repositories(ctx)
+    describe_ret = await hub.exec.aws.ecr.repository.list(ctx)
     if not describe_ret["result"]:
         hub.log.debug(f"Could not describe repository: {describe_ret['comment']}")
         return result
 
-    for repository in describe_ret["ret"].get("repositories"):
-        resource_id = repository.get("repositoryName")
-
-        tags_ret = await hub.exec.boto3.client.ecr.list_tags_for_resource(
-            ctx, resourceArn=repository.get("repositoryArn")
-        )
-        if not tags_ret["result"]:
-            hub.log.debug(
-                f"Could not list tags for repository '{resource_id}': {tags_ret['comment']}"
-            )
-
-        resource_translated = (
-            hub.tool.aws.ecr.conversion_utils.convert_raw_repository_to_present(
-                raw_resource=repository,
-                tags=tags_ret.get("ret").get("tags")
-                if tags_ret.get("result")
-                else None,
-                idem_resource_name=resource_id,
-            )
-        )
-
+    for repository in describe_ret["ret"]:
+        resource_id = repository.get("repository_name")
         result[resource_id] = {
             "aws.ecr.repository.present": [
                 {parameter_key: parameter_value}
-                for parameter_key, parameter_value in resource_translated.items()
+                for parameter_key, parameter_value in repository.items()
             ]
         }
 
@@ -448,6 +384,9 @@ async def search(
                 - resource_id: idem_test_ecr_repository
                 - registry_id: idem_test_ecr_registry
     """
+    hub.log.warning(
+        f"aws.ecr.repository.search '{name}' state has been deprecated. Please use exec.run with aws.ecr.repository.get instead."
+    )
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
 
     describe_ret = await hub.exec.boto3.client.ecr.describe_repositories(
