@@ -67,7 +67,6 @@ async def present(
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
 
-    before_ret = None
     resource_updated = False
     policy_text = hub.tool.aws.state_comparison_utils.standardise_json(policy_text)
 
@@ -75,26 +74,18 @@ async def present(
         if registry_id is None:
             registry_id = resource_id.split("-")[0]
 
-    before_ret = await hub.exec.boto3.client.ecr.get_repository_policy(
-        ctx, registryId=registry_id, repositoryName=repository_name
+    before_ret = await hub.exec.aws.ecr.repository_policy.get(
+        ctx,
+        name=repository_name,
+        registry_id=registry_id,
+        resource_id=repository_name,
     )
-    if not before_ret["result"]:
-        if "RepositoryNotFoundException" not in str(
-            before_ret["comment"][0]
-        ) and "RepositoryPolicyNotFoundException" not in str(before_ret["comment"][0]):
-            result["result"] = False
-            result["comment"] = before_ret["comment"]
-            return result
 
-    if before_ret:
+    # Case: If there is something found
+    if before_ret["result"] and before_ret["ret"]:
         result["comment"] = (f"aws.ecr.repository_policy '{name}' already exists",)
-        result[
-            "old_state"
-        ] = hub.tool.aws.ecr.conversion_utils.convert_raw_repository_policy_to_present(
-            raw_resource=before_ret.get("ret"),
-            idem_resource_name=name,
-        )
-        result["new_state"] = copy.deepcopy(result["old_state"])
+        result["old_state"] = copy.deepcopy(before_ret.get("ret"))
+        result["new_state"] = copy.deepcopy(before_ret.get("ret"))
 
         if policy_text and not hub.tool.aws.state_comparison_utils.is_json_identical(
             result["old_state"]["policy_text"], policy_text
@@ -157,21 +148,18 @@ async def present(
             resource_type="aws.ecr.repository_policy", name=name
         )
 
+    # Case: If something got updated or old_state is not present
     if (not result["old_state"]) or resource_updated:
-        after_ret = await hub.exec.boto3.client.ecr.get_repository_policy(
-            ctx, registryId=registry_id, repositoryName=repository_name
+        after_ret = await hub.exec.aws.ecr.repository_policy.get(
+            ctx, name=name, registry_id=registry_id, resource_id=repository_name
         )
+
         if not after_ret["result"]:
             result["result"] = False
             result["comment"] = result["comment"] + after_ret["comment"]
             return result
 
-        result[
-            "new_state"
-        ] = hub.tool.aws.ecr.conversion_utils.convert_raw_repository_policy_to_present(
-            raw_resource=after_ret.get("ret"),
-            idem_resource_name=name,
-        )
+        result["new_state"] = copy.deepcopy(after_ret.get("ret"))
 
     return result
 
@@ -235,29 +223,30 @@ async def absent(
         if registry_id is None:
             registry_id = resource_id.split("-")[0]
 
-    before_ret = await hub.exec.boto3.client.ecr.get_repository_policy(
-        ctx, registryId=registry_id, repositoryName=repository_name
+    before_ret = await hub.exec.aws.ecr.repository_policy.get(
+        ctx,
+        name=name,
+        registry_id=registry_id,
+        resource_id=repository_name,
     )
+
+    # Case: Error
     if not before_ret["result"]:
-        if "RepositoryNotFoundException" in str(
-            before_ret["comment"][0]
-        ) or "RepositoryPolicyNotFoundException" in str(before_ret["comment"][0]):
-            result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
-                resource_type="aws.ecr.repository_policy", name=name
-            )
-        else:
-            result["result"] = False
-            result["comment"] = before_ret["comment"]
+        result["result"] = False
+        result["comment"] = before_ret["comment"]
         return result
 
-    result[
-        "old_state"
-    ] = hub.tool.aws.ecr.conversion_utils.convert_raw_repository_policy_to_present(
-        raw_resource=before_ret.get("ret"),
-        idem_resource_name=name,
-    )
+    # Any case forward, the old_state should carry current state in old_state
+    result["old_state"] = copy.deepcopy(before_ret["ret"])
 
-    if ctx.get("test", False):
+    if not before_ret["ret"]:
+        # Case: already absent
+        result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
+            resource_type="aws.ecr.repository_policy", name=name
+        )
+        return result
+    elif ctx.get("test", False):
+        # Case: --test context
         result["comment"] = hub.tool.aws.comment_utils.would_delete_comment(
             resource_type="aws.ecr.repository_policy", name=name
         )
@@ -266,11 +255,14 @@ async def absent(
     delete_ret = await hub.exec.boto3.client.ecr.delete_repository_policy(
         ctx, registryId=registry_id, repositoryName=repository_name
     )
-    if not result["result"]:
+
+    # Case: Failed to delete
+    if not delete_ret["result"]:
         result["result"] = False
         result["comment"] = delete_ret["comment"]
         return result
 
+    # Case: All good, add deleted comment
     result["comment"] = hub.tool.aws.comment_utils.delete_comment(
         resource_type="aws.ecr.repository_policy", name=name
     )
@@ -293,20 +285,23 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
 
     # To describe all the repository policies, we first need to list all the repositories,
     # and then we get the policy associated to each repository
-    describe_ret = await hub.exec.boto3.client.ecr.describe_repositories(ctx)
+    describe_ret = await hub.exec.aws.ecr.repository.list(ctx)
     if not describe_ret["result"]:
         hub.log.warning(f"Could not describe repositories: {describe_ret['comment']}")
         return result
 
-    for repository in describe_ret["ret"].get("repositories"):
-        registry_id = repository.get("registryId")
-        repository_name = repository.get("repositoryName")
+    for repository in describe_ret["ret"]:
+        registry_id = repository.get("registry_id")
+        repository_name = repository.get("name")
 
-        get_policy_ret = await hub.exec.boto3.client.ecr.get_repository_policy(
+        get_policy_ret = await hub.exec.aws.ecr.repository_policy.get(
             ctx,
-            registryId=registry_id,
-            repositoryName=repository_name,
+            name=repository_name,
+            registry_id=registry_id,
+            resource_id=repository_name,
         )
+
+        # Case: failure to get a policy
         if not get_policy_ret["result"]:
             hub.log.warning(
                 f"Could not get policy for repository '{registry_id}/{repository_name}': "
@@ -314,16 +309,19 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
             )
             continue
 
-        resource_translated = (
-            hub.tool.aws.ecr.conversion_utils.convert_raw_repository_policy_to_present(
-                raw_resource=get_policy_ret.get("ret"),
+        # Case: There is no policy for the repository
+        if not get_policy_ret.get("ret"):
+            hub.log.debug(
+                f"No policy for repository '{registry_id}/{repository_name}' exists: "
+                f"{get_policy_ret['comment']}. Describe will skip this repository and continue."
             )
-        )
+            continue
 
-        result[resource_translated.get("name")] = {
+        resource = get_policy_ret.get("ret")
+        result[resource.get("name")] = {
             "aws.ecr.repository_policy.present": [
                 {parameter_key: parameter_value}
-                for parameter_key, parameter_value in resource_translated.items()
+                for parameter_key, parameter_value in resource.items()
             ]
         }
 
@@ -365,6 +363,9 @@ async def search(
                 - repository_name: idem_test_ecr_repository
                 - registry_id: idem_test_ecr_registry
     """
+    hub.log.warning(
+        f"aws.ecr.repository_policy.search '{name}' state has been deprecated. Please use exec.run with aws.ecr.repository_policy.get instead."
+    )
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
 
     get_policy_ret = await hub.exec.boto3.client.ecr.get_repository_policy(
