@@ -123,7 +123,7 @@ async def present(
         ],
     ) = None,
 ) -> Dict[str, Any]:
-    r"""Creates an Amazon EKS control plane.
+    """Creates an Amazon EKS control plane.
 
     The Amazon EKS control plane consists of control plane instances that run the Kubernetes software, such as etcd and
     the API server. The control plane runs in an account managed by Amazon Web Services, and the Kubernetes API is
@@ -388,7 +388,9 @@ async def present(
     before = None
     resource_updated = False
     if resource_id:
-        before = await hub.exec.eks.cluster.get(ctx, name=name, resource_id=resource_id)
+        before = await hub.exec.aws.eks.cluster.get(
+            ctx, name=name, resource_id=resource_id
+        )
         if not before["result"]:
             result["result"] = False
             result["comment"] = before["comment"]
@@ -499,7 +501,9 @@ async def present(
         if ctx.get("test", False):
             result["new_state"] = plan_state
         elif (not before) or resource_updated:
-            after = await hub.exec.eks.get(ctx, name=name, resource_id=resource_id)
+            after = await hub.exec.aws.eks.cluster.get(
+                ctx, name=name, resource_id=resource_id
+            )
             if not after["result"]:
                 result["result"] = False
                 result["comment"] = after["comment"]
@@ -571,7 +575,7 @@ async def absent(
             resource_type="aws.eks.cluster", name=name
         )
         return result
-    before = await hub.exec.eks.cluster.get(ctx, name=name, resource_id=resource_id)
+    before = await hub.exec.aws.eks.cluster.get(ctx, name=name, resource_id=resource_id)
 
     if not before["ret"]:
         result["comment"] = hub.tool.aws.comment_utils.already_absent_comment(
@@ -647,7 +651,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         return {}
 
     for name in ret["ret"]["clusters"]:
-        get_ret = await hub.exec.eks.cluster.get(ctx, name=name, resource_id=name)
+        get_ret = await hub.exec.aws.eks.cluster.get(ctx, name=name, resource_id=name)
         if not get_ret["result"] or not get_ret["ret"]:
             hub.log.debug(f"Could not get cluster {name}, Error:  {get_ret['comment']}")
             continue
@@ -665,10 +669,10 @@ async def search(hub, ctx, name, resource_id: str = None):
     """Provides details about a specific Cluster.
 
     Args:
-        name(Text):
+        name(str):
              An Idem name of the EKS cluster resource.
 
-        resource_id(Text, optional):
+        resource_id(str, Optional):
             AWS EKS cluster name to identify the resource.
 
 
