@@ -66,7 +66,7 @@ async def present(
         ],
     ) = None,
 ) -> Dict[str, Any]:
-    r"""Creates an Fargate profile for your Amazon EKS cluster.
+    """Creates an Fargate profile for your Amazon EKS cluster.
 
     You must have at least one Fargate profile in a cluster to be able to run pods on Fargate. The Fargate profile allows
     an administrator to declare which pods run on Fargate and specify which pods run on which Fargate profile. This
@@ -263,7 +263,7 @@ async def absent(
     resource_id: str = None,
     timeout: Dict = None,
 ) -> Dict[str, Any]:
-    r"""Deletes an Fargate profile.
+    """Deletes an Fargate profile.
 
     When you delete a Fargate profile, any pods running on Fargate that were created with the profile are deleted. If
     those pods match another Fargate profile, then they are scheduled on Fargate with that profile. If they no longer
@@ -369,7 +369,7 @@ async def absent(
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""
+    """
     Describe the resource in a way that can be recreated/managed with the corresponding "present" function.
 
     Lists the Fargate profiles associated with the specified cluster in your Amazon Web Services account in the
