@@ -234,15 +234,7 @@ async def present(
         function = before["ret"].get("Configuration")
         code_config = before["ret"].get("Code")
         function_arn = function.get("FunctionArn")
-        tags_return = await hub.exec.boto3.client["lambda"].list_tags(
-            ctx, Resource=function_arn
-        )
-        result["result"] = tags_return.get("result")
-        if result["result"]:
-            existing_tags = tags_return.get("ret").get("Tags")
-        else:
-            result["comment"] = result["comment"] + tags_return["comment"]
-            return result
+        existing_tags = before.get("ret").get("Tags")
         resource_converted = await hub.tool.aws.lambda_aws.conversion_utils.convert_raw_lambda_function_to_present(
             ctx,
             raw_resource=function,
@@ -419,13 +411,9 @@ async def present(
         after = await hub.exec.boto3.client["lambda"].get_function(
             ctx, FunctionName=resource_id, Qualifier=qualifier
         )
-        final_updated_tags = existing_tags
-        if are_tags_updated:
-            tags = await hub.exec.boto3.client["lambda"].list_tags(
-                ctx, Resource=function_arn
-            )
-            if tags.get("result") and tags.get("ret"):
-                final_updated_tags = tags.get("ret").get("Tags")
+        final_updated_tags = (
+            after.get("ret").get("Tags") if are_tags_updated else existing_tags
+        )
         resource_converted = await hub.tool.aws.lambda_aws.conversion_utils.convert_raw_lambda_function_to_present(
             ctx=ctx,
             raw_resource=after["ret"].get("Configuration"),
@@ -492,16 +480,7 @@ async def absent(
     if not before["result"]:
         result["comment"] = (f"aws.lambda.function '{name}' already absent",)
     else:
-        tags = await hub.exec.boto3.client["lambda"].list_tags(
-            ctx, Resource=before["ret"].get("Configuration").get("FunctionArn")
-        )
-        if tags.get("result"):
-            existing_tags = tags.get("ret").get("Tags")
-        else:
-            result["comment"] = result["comment"] + tags["comment"]
-            result["result"] = False
-            return result
-
+        existing_tags = before.get("ret").get("Tags")
         resource_converted = await hub.tool.aws.lambda_aws.conversion_utils.convert_raw_lambda_function_to_present(
             ctx,
             raw_resource=before["ret"].get("Configuration"),
