@@ -474,7 +474,7 @@ async def present(
                 operation="DescribeDBClusters",
                 argument=["DBClusters[].Status"],
                 acceptors=create_waiter_acceptors,
-                client=hub.tool.boto3.client.get_client(ctx, "neptune"),
+                client=await hub.tool.boto3.client.get_client(ctx, "neptune"),
             )
             try:
                 await hub.tool.boto3.client.wait(
@@ -671,7 +671,7 @@ async def absent(
         operation="DescribeDBClusters",
         argument=["Error.Code", "DBClusters[].Status"],
         acceptors=delete_waiter_acceptors,
-        client=hub.tool.boto3.client.get_client(ctx, "neptune"),
+        client=await hub.tool.boto3.client.get_client(ctx, "neptune"),
     )
     try:
         await hub.tool.boto3.client.wait(
