@@ -313,7 +313,7 @@ async def present(
 
 
 async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]:
-    r"""Deletes a hosted zone.
+    """Deletes a hosted zone.
 
     If the hosted zone was created by another service, such as Cloud Map, see Deleting Public Hosted Zones That Were
     Created by Another Service in the Amazon Route 53 Developer Guide for information about how to delete it.
@@ -407,7 +407,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    r"""Describe the resource in a way that can be recreated/managed with the corresponding "present" function
+    """Describe the resource in a way that can be recreated/managed with the corresponding "present" function
 
     Retrieves a list of the public and private hosted zones that are associated with the current Amazon Web Services
     account.
