@@ -17,7 +17,7 @@ async def present(
     resource_id: str = None,
     ttl: int = None,
 ) -> Dict[str, Any]:
-    r"""Creates or changes a resource record set, which contains authoritative DNS information for a specified domain name
+    """Creates or changes a resource record set, which contains authoritative DNS information for a specified domain name
     or subdomain name.
 
     Args:
@@ -185,7 +185,7 @@ async def present(
 
 
 async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]:
-    r"""Deletes the specified resource record
+    """Deletes the specified resource record
 
     Args:
         name(str):
@@ -319,7 +319,10 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
                 hosted_zone_id=hosted_zone_id, raw_resource=resource_record_set
             )
             result[resource_translated["resource_id"]] = {
-                "aws.route53.resource_record.present": [resource_translated]
+                "aws.route53.resource_record.present": [
+                    {parameter_key: parameter_value}
+                    for parameter_key, parameter_value in resource_translated.items()
+                ]
             }
 
     return result
