@@ -68,7 +68,7 @@ async def present(
         acl(str, Optional):
             The associated acl for this bucket ('private', 'public-read', 'public-read-write', 'authenticated-read').
 
-        create_bucket_configuration(Dict[str, Any], Optional):
+        create_bucket_configuration(dict[str, Any], Optional):
             The configuration information for the bucket. Defaults to None.
             LocationConstraint (str, Optional): Specifies the Region where the bucket will be created.
             If you don't specify a Region, the bucket is created in the US East (N. Virginia) Region (us-east-1).
@@ -133,7 +133,7 @@ async def present(
                         The number of years that you want to specify for the default retention period. Must be used with Mode .
 
         tags(dict or list, Optional):
-            Dict in the format of ``{tag-key: tag-value}`` or List of tags in the format of
+            dict in the format of ``{tag-key: tag-value}`` or List of tags in the format of
             ``[{"Key": tag-key, "Value": tag-value}]`` to associate with the AMI.
 
             * Key (str):
@@ -150,7 +150,7 @@ async def present(
                 in your code.
 
     Request Syntax:
-       .. code-block:: sls
+       .. code-block:: yaml
 
             [s3-resource-id]:
               aws.s3.bucket.present:
@@ -176,10 +176,10 @@ async def present(
                       Value: "string"
 
     Returns:
-        Dict[str, Any]
+        dict[str, Any]
 
     Examples:
-        .. code-block:: sls
+        .. code-block:: yaml
 
             test_bucket-bb7bb32e9533:
               aws.s3.bucket.present:
@@ -200,8 +200,6 @@ async def present(
                       Value: "s3-test1"
                     - Key: "Name2"
                       Value: "s3-test2"
-
-
     """
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     before = None
@@ -356,12 +354,14 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
     """Delete the specified s3 bucket.
 
     Args:
-        name(str): The Idem name of the s3 bucket.
+        name(str):
+            The Idem name of the s3 bucket.
 
-        resource_id(str, Optional): AWS S3 Bucket name.
+        resource_id(str, Optional):
+            AWS S3 Bucket name.
 
     Request Syntax:
-        .. code-block:: sls
+        .. code-block:: yaml
 
             idem-name:
               aws.s3.bucket.absent:
@@ -369,10 +369,10 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
                 - resource_id: value
 
     Returns:
-        Dict[str, Any]
+        dict[str, Any]
 
     Examples:
-        .. code-block:: sls
+        .. code-block:: yaml
 
             bucket-5435423646-456464:
               aws.s3.bucket.absent:
@@ -426,7 +426,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
     """Describe the AWS bucket in a way that can be recreated/managed with the corresponding "present" function.
 
     Returns:
-        Dict[str, Dict[str, Any]]
+        dict[str, dict[str, Any]]
 
     Examples:
         .. code-block:: bash
