@@ -7,12 +7,12 @@ from typing import Dict
 def convert_raw_stage_to_present(
     hub, api_id: str, raw_resource: Dict[str, Any]
 ) -> Dict[str, Any]:
-    r"""
+    """
     Convert AWS API Gateway v2 Stage resource to a common idem present state.
 
     Args:
         hub: required for functions in hub.
-        api_id(string): The API resource identifier in Amazon Web Services.
+        api_id(str): The API resource identifier in Amazon Web Services.
         raw_resource(Dict[str, Any]): The AWS response to convert.
 
     Returns:
