@@ -521,6 +521,44 @@ def convert_raw_sg_to_present(hub, security_group: Dict):
     return translated_security_group
 
 
+def convert_raw_sir_to_present(hub, spot_instance_request: Dict):
+    """
+    Convert the aws spot instance request response to a common format
+
+    Args:
+        hub: required for functions in hub
+        spot_instance_request: describe security group response
+
+    Returns:
+        A dictionary of sg group
+    """
+    translated_spot_instance_request = {}
+    describe_parameters = OrderedDict(
+        {
+            "CreateTime": "create-time",
+            "InstanceId": "instance-id",
+            "ProductDescription": "product-description",
+            "SpotInstanceRequestId": "spot-instance-request-id",
+            "SpotPrice": "spot-price",
+            "State": "state",
+            "Type": "type",
+        }
+    )
+    for parameter_old_key, parameter_new_key in describe_parameters.items():
+        if spot_instance_request.get(parameter_old_key) is not None:
+            translated_spot_instance_request[
+                parameter_new_key
+            ] = spot_instance_request.get(parameter_old_key)
+    if "Tags" in spot_instance_request:
+        translated_spot_instance_request[
+            "tags"
+        ] = hub.tool.aws.tag_utils.convert_tag_list_to_dict(
+            spot_instance_request.get("Tags")
+        )
+
+    return translated_spot_instance_request
+
+
 def convert_raw_internet_gateway_to_present(
     hub, resource: Dict[str, Any], idem_resource_name: str = None
 ) -> Dict[str, Any]:
@@ -578,7 +616,7 @@ def convert_raw_elastic_ip_to_present(
     Args:
         hub: required for functions in hub
         raw_resource (Dict): The dictionary object from where the raw state of resource needs to be translated.
-        idem_resource_name (Text): The name of the idem resource
+        idem_resource_name (str): The name of the idem resource
 
     Returns: Dict[str, Any]
     """
@@ -634,6 +672,7 @@ def convert_raw_vpc_endpoint_to_present(
             "SecurityGroupIds": "security_group_ids",
             "PrivateDnsEnabled": "private_dns_enabled",
             "State": "state",
+            "DnsOptions": "dns_options",
         }
     )
     resource_id = raw_resource.get("VpcEndpointId")
@@ -645,6 +684,11 @@ def convert_raw_vpc_endpoint_to_present(
         resource_translated["tags"] = hub.tool.aws.tag_utils.convert_tag_list_to_dict(
             raw_resource.get("Tags")
         )
+    if raw_resource.get("Groups"):
+        security_group_ids = []
+        for security_group in raw_resource.get("Groups"):
+            security_group_ids.append(security_group.get("GroupId"))
+        resource_translated["security_group_ids"] = security_group_ids
 
     return resource_translated
 
@@ -872,3 +916,35 @@ def convert_raw_vpc_peering_connection_accepter_to_present(
     }
 
     return resource_translated
+
+
+def convert_raw_lauchtemplate_to_present(
+    hub,
+    raw_resource: Dict[str, Any],
+    raw_version: Dict[str, Any],
+    idem_resource_name: str = None,
+) -> Dict[str, Any]:
+    resource_id = raw_resource.get("LaunchTemplateId")
+    resource_parameters = OrderedDict(
+        {
+            "LaunchTemplateName": "name",
+            "CreatedBy": "created_by",
+            "DefaultVersionNumber": "default_version_number",
+            "LatestVersionNumber": "latest_version_number",
+        }
+    )
+    resource_translated = {"resource_id": resource_id}
+    for parameter_raw, parameter_present in resource_parameters.items():
+        if parameter_raw in raw_resource:
+            resource_translated[parameter_present] = raw_resource.get(parameter_raw)
+    if "CreateTime" in raw_resource:
+        local_time = raw_resource.get("CreateTime").astimezone()
+        start_time = local_time.astimezone(timezone.utc).strftime(UTC_FORMAT)
+        resource_translated["create_time"] = start_time
+    if "Tags" in raw_resource:
+        resource_translated["tags"] = hub.tool.aws.tag_utils.convert_tag_list_to_dict(
+            raw_resource.get("Tags")
+        )
+    resource_translated["version_description"] = raw_version.get("VersionDescription")
+    resource_translated["launch_template_data"] = raw_version.get("LaunchTemplateData")
+    return resource_translated
