@@ -21,7 +21,7 @@ async def update_tags(
     Args:
         hub:
         ctx:
-        resource_arn(Text): aws elasticache arn
+        resource_arn(str): aws elasticache arn
         old_tags(Dict[str, Any]): dict of old tags in the format of {tag-key: tag-value}
         new_tags(Dict[str, Any]): dict of new tags in the format of {tag-key: tag-value}. If this value is None, the function will do no operation on tags.
         waiter: waiter function to wait for the resource to be in available status after update.
@@ -101,7 +101,7 @@ async def update_tags(
 
 def get_updated_cache_parameter_group(hub, old_paramaters, parameter_name_values):
 
-    r"""
+    """
     Checks if the input ParameterNamesValues needs to be updated and returns a list of parameters that needs to be modified.
 
     Args:
@@ -205,54 +205,54 @@ async def update_replication_group(
     Note: This operation is valid for Redis only.
 
     Args:
-        name(Text): An Idem name of the resource. It is used as ReplicationGroupID during resource creation
-        resource_id(Text, optional): An identifier of the resource in the provider. Defaults to None.
-        replication_group_description(Text): A user-created description for the replication group.
-        primary_cluster_id(Text, optional): The identifier of the cluster that serves as the primary for this replication group. This
+        name(str): An Idem name of the resource. It is used as ReplicationGroupID during resource creation
+        resource_id(str, Optional): An identifier of the resource in the provider. Defaults to None.
+        replication_group_description(str): A user-created description for the replication group.
+        primary_cluster_id(str, Optional): The identifier of the cluster that serves as the primary for this replication group. This
             cluster must already exist and have a status of available. This parameter is not required if
             NumCacheClusters, NumNodeGroups, or ReplicasPerNodeGroup is specified. Defaults to None.
-        snapshotting_cluster_id (Text, optional): The cluster ID that is used as the daily snapshot source for the replication group. This parameter
+        snapshotting_cluster_id (str, Optional): The cluster ID that is used as the daily snapshot source for the replication group. This parameter
                     cannot be set for Redis (cluster mode enabled) replication groups.
-        automatic_failover_enabled(bool, optional): Specifies whether a read-only replica is automatically promoted to read/write primary if the
+        automatic_failover_enabled(bool, Optional): Specifies whether a read-only replica is automatically promoted to read/write primary if the
             existing primary fails.  AutomaticFailoverEnabled must be enabled for Redis (cluster mode
             enabled) replication groups. Default: false. Defaults to None.
-        multi_az_enabled(bool, optional): A flag indicating if you have Multi-AZ enabled to enhance fault tolerance. For more information,
+        multi_az_enabled(bool, Optional): A flag indicating if you have Multi-AZ enabled to enhance fault tolerance. For more information,
             see Minimizing Downtime: Multi-AZ. Defaults to None.
-        node_group_id(Text, optional): Deprecated. This parameter is not used.
-        notification_topic_status(bool, optional): The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications are sent.
-        apply_immediately(bool, optional): If true , this parameter causes the modifications in this request and any pending modifications to be applied,
+        node_group_id(str, Optional): Deprecated. This parameter is not used.
+        notification_topic_status(bool, Optional): The Amazon Resource Name (ARN) of the Amazon SNS topic to which notifications are sent.
+        apply_immediately(bool, Optional): If true , this parameter causes the modifications in this request and any pending modifications to be applied,
             asynchronously and as soon as possible, regardless of the PreferredMaintenanceWindow setting for the replication group.
             If false , changes to the nodes in the replication group are applied on the next maintenance reboot, or the next failure reboot,
             whichever occurs first.
             Valid values: true | false
             Default: false
-        cache_security_group_names(List[str], optional): A list of cache security group names to associate with this replication group. Defaults to None.
-        security_group_ids(List[str], optional): One or more Amazon VPC security groups associated with this replication group. Use this
+        cache_security_group_names(List[str], Optional): A list of cache security group names to associate with this replication group. Defaults to None.
+        security_group_ids(List[str], Optional): One or more Amazon VPC security groups associated with this replication group. Use this
             parameter only when you are creating a replication group in an Amazon Virtual Private Cloud
             (Amazon VPC). Defaults to None.
-        preferred_maintenance_window(Text, optional): Specifies the weekly time range during which maintenance on the cluster is performed. It is
+        preferred_maintenance_window(str, Optional): Specifies the weekly time range during which maintenance on the cluster is performed. It is
             specified as a range in the format ddd:hh24:mi-ddd:hh24:mi (24H Clock UTC). The minimum
             maintenance window is a 60 minute period. Valid values for ddd are: Specifies the weekly time
             range during which maintenance on the cluster is performed. It is specified as a range in the
             format ddd:hh24:mi-ddd:hh24:mi (24H Clock UTC). The minimum maintenance window is a 60 minute
             period. Valid values for ddd are:    sun     mon     tue     wed     thu     fri     sat
             Example: sun:23:00-mon:01:30. Defaults to None.
-        engine_version(Text, optional): The version number of the cache engine to be used for the clusters in this replication group. To
+        engine_version(str, Optional): The version number of the cache engine to be used for the clusters in this replication group. To
             view the supported cache engine versions, use the DescribeCacheEngineVersions operation.
             Important: You can upgrade to a newer engine version (see Selecting a Cache Engine and Version)
             in the ElastiCache User Guide, but you cannot downgrade to an earlier engine version. If you
             want to use an earlier engine version, you must delete the existing cluster or replication group
             and create it anew with the earlier engine version. Defaults to None.
-        auto_minor_version_upgrade(bool, optional):  If you are running Redis engine version 6.0 or later, set this parameter to yes if you want to
+        auto_minor_version_upgrade(bool, Optional):  If you are running Redis engine version 6.0 or later, set this parameter to yes if you want to
             opt-in to the next auto minor version upgrade campaign. This parameter is disabled for previous
             versions. . Defaults to None.
-        snapshot_retention_limit(int, optional): The number of days for which ElastiCache retains automatic snapshots before deleting them. For
+        snapshot_retention_limit(int, Optional): The number of days for which ElastiCache retains automatic snapshots before deleting them. For
             example, if you set SnapshotRetentionLimit to 5, a snapshot that was taken today is retained for
             5 days before being deleted. Default: 0 (i.e., automatic backups are disabled for this cluster). Defaults to None.
-        snapshot_window(Text, optional): The daily time range (in UTC) during which ElastiCache begins taking a daily snapshot of your
+        snapshot_window(str, Optional): The daily time range (in UTC) during which ElastiCache begins taking a daily snapshot of your
             node group (shard). Example: 05:00-09:00  If you do not specify this parameter, ElastiCache
             automatically chooses an appropriate time range. Defaults to None.
-        auth_token(Text, optional):  Reserved parameter. The password used to access a password protected server.  AuthToken can be
+        auth_token(str, Optional):  Reserved parameter. The password used to access a password protected server.  AuthToken can be
             specified only on replication groups where TransitEncryptionEnabled is true.  For HIPAA
             compliance, you must specify TransitEncryptionEnabled as true, an AuthToken, and a
             CacheSubnetGroup.  Password constraints:   Must be only printable ASCII characters.   Must be at
@@ -260,30 +260,30 @@ async def update_replication_group(
             special characters are !, &, #, $, ^, <, >, and -. Other printable special characters cannot be
             used in the AUTH token.   For more information, see AUTH password at
             http://redis.io/commands/AUTH. Defaults to None.
-        cache_node_type(Text, optional): The compute and memory capacity of the nodes in the node group (shard). The following node types
+        cache_node_type(str, Optional): The compute and memory capacity of the nodes in the node group (shard). The following node types
             are supported by ElastiCache. Generally speaking, the current generation types provide more
             memory and computational power at lower cost when compared to their equivalent previous
             generation counterparts.
-        auto_token_update_strategy(Text, optional): Specifies the strategy to use to update the AUTH token. This parameter must be specified with
+        auto_token_update_strategy(str, Optional): Specifies the strategy to use to update the AUTH token. This parameter must be specified with
                 the auth-token parameter. Possible values:
                 Rotate
                 Set
                 For more information, see Authenticating Users with Redis AUTH
-        user_group_ids_to_add(List[str], optional): The ID of the user group you are associating with the replication group.
-        user_group_ids_to_remove(List[str], optional): The ID of the user group to disassociate from the replication group, meaning the users in
+        user_group_ids_to_add(List[str], Optional): The ID of the user group you are associating with the replication group.
+        user_group_ids_to_remove(List[str], Optional): The ID of the user group to disassociate from the replication group, meaning the users in
                 the group no longer can access the replication group.
-        remove_user_groups(bool, optional): Removes the user group associated with this replication group.
-        log_delivery_configurations(List[Dict], optional): Specifies the destination, format and type of the logs. Defaults to None.
-            * LogType (Text, optional): Refers to slow-log.
-            * DestinationType (Text, optional): Specify either cloudwatch-logs or kinesis-firehose as the destination type.
-            * DestinationDetails (Text, optional): Configuration details of either a CloudWatch Logs destination or Kinesis Data Firehose
+        remove_user_groups(bool, Optional): Removes the user group associated with this replication group.
+        log_delivery_configurations(List[Dict], Optional): Specifies the destination, format and type of the logs. Defaults to None.
+            * LogType (str, Optional): Refers to slow-log.
+            * DestinationType (str, Optional): Specify either cloudwatch-logs or kinesis-firehose as the destination type.
+            * DestinationDetails (str, Optional): Configuration details of either a CloudWatch Logs destination or Kinesis Data Firehose
             destination.
-                * CloudWatchLogsDetails (Dict, optional): The configuration details of the CloudWatch Logs destination.
-                    * LogGroup (Text, optional): The name of the CloudWatch Logs log group.
-                * KinesisFirehoseDetails (Dict, optional): The configuration details of the Kinesis Data Firehose destination.
-                    * DeliveryStream (str, optional): The name of the Kinesis Data Firehose delivery stream.
-            * LogFormat (Text, optional): Specifies either JSON or TEXT
-            * Enabled (bool, optional): Specify if log delivery is enabled. Default true.
+                * CloudWatchLogsDetails (Dict, Optional): The configuration details of the CloudWatch Logs destination.
+                    * LogGroup (str, Optional): The name of the CloudWatch Logs log group.
+                * KinesisFirehoseDetails (Dict, Optional): The configuration details of the Kinesis Data Firehose destination.
+                    * DeliveryStream (str, Optional): The name of the Kinesis Data Firehose delivery stream.
+            * LogFormat (str, Optional): Specifies either JSON or TEXT
+            * Enabled (bool, Optional): Specify if log delivery is enabled. Default true.
 
     Returns:
         {"result": True|False, "comment": A message Tuple, "ret": Dict}
@@ -359,16 +359,16 @@ async def replication_group_waiter(
     Waiter to wait for the replication group to become active.
 
         Args:
-           name(Text): An Idem name of the resource. It is used as ReplicationGroupID during resource creation
-           resource_id(Text): Replication group id to Identify the resource
-           timeout(Dict, optional): Timeout configuration for creating or updating replication group.
+           name(str): An Idem name of the resource. It is used as ReplicationGroupID during resource creation
+           resource_id(str): Replication group id to Identify the resource
+           timeout(Dict, Optional): Timeout configuration for creating or updating replication group.
             * create (Dict) -- Timeout configuration for creating replication group
                 * delay(int, default=60) -- The amount of time in seconds to wait between attempts.
                 * max_attempts(int, default=40) -- Customized timeout configuration containing delay and max attempts.
-            * update (Text) -- Timeout configuration for updating replication group
+            * update (str) -- Timeout configuration for updating replication group
                 * delay(int, default=60) -- The amount of time in seconds to wait between attempts.
                 * max_attempts(int, default=40) -- Customized timeout configuration containing delay and max attempts.
-           operation_type(Text): create or update operation
+           operation_type(str): create or update operation
 
         Returns:
             Dict[str, Any]
