@@ -11,15 +11,15 @@ def convert_raw_load_balancer_to_present(
     tags: Dict[str, str] = None,
     attributes: List[Dict[str, str]] = None,
 ) -> Dict[str, Any]:
-    r"""
+    """
     Util function to convert raw resource state from AWS ElasticLoadBalancingv2 Load Balancer to present input format.
 
     Args:
         raw_resource(Dict[str, Any]):
             The AWS response from 'ElasticLoadBalancingv2 describe_load_balancers' to convert.
-        idem_resource_name(Text, optional): An Idem name of the resource.
-        tags(Dict[str, str], optional): The AWS ElasticLoadBalancingv2 Load Balancer tags.
-        attributes(List[Dict[str, str]], optional):
+        idem_resource_name(str, Optional): An Idem name of the resource.
+        tags(Dict[str, str], Optional): The AWS ElasticLoadBalancingv2 Load Balancer tags.
+        attributes(List[Dict[str, str]], Optional):
             List of attributes associated with given ElasticLoadBalancingv2 Load Balancer.
 
     Returns:
@@ -85,16 +85,16 @@ def convert_raw_target_group_to_present(
     attributes: List[Dict[str, str]] = None,
     targets: List[Dict[str, Any]] = None,
 ) -> Dict[str, Any]:
-    r"""
+    """
     Util function to convert raw resource state from ElasticLoadBalancingv2 Target Group to present input format.
 
     Args:
         raw_resource(Dict[str, Any]): The AWS response from 'ElasticLoadBalancingv2 describe_target_groups' to convert.
-        idem_resource_name(Text, optional): An Idem name of the resource.
-        tags(Dict[str, str], optional): The AWS ElasticLoadBalancingv2 Target Group tags.
-        attributes(List[Dict[str, str]], optional):
+        idem_resource_name(str, Optional): An Idem name of the resource.
+        tags(Dict[str, str], Optional): The AWS ElasticLoadBalancingv2 Target Group tags.
+        attributes(List[Dict[str, str]], Optional):
             List of attributes associated with given ElasticLoadBalancingv2 Target Group.
-        targets(List[Dict[str, Any]], optional):
+        targets(List[Dict[str, Any]], Optional):
             List of targets associated with given ElasticLoadBalancingv2 Target Group.
 
     Returns:
@@ -146,20 +146,20 @@ def convert_raw_listener_to_present(
     tags: Dict[str, str] = None,
     certificates: List[Dict[str, Any]] = None,
 ) -> Dict[str, Any]:
-    r"""
+    """
     Util functions to convert raw resource state from AWS ELBv2 Listener to present input format.
 
     Args:
         raw_resource(dict[str, Any]):
             The AWS response from 'ElasticLoadBalancingv2 describe_listeners' to convert.
 
-        idem_resource_name(str, optional):
+        idem_resource_name(str, Optional):
             An Idem name of the resource.
 
-        tags(dict[str, str], optional):
+        tags(dict[str, str], Optional):
             The AWS ElasticLoadBalancingv2 Listener tags.
 
-        certificates(list[dict[str, Any]], optional):
+        certificates(list[dict[str, Any]], Optional):
             List of certificates associated with given ElasticLoadBalancingv2 Listener.
 
     Returns:
