@@ -26,7 +26,7 @@ async def convert_raw_detector_to_present(
             resource_translated[parameter_present] = raw_resource["ret"].get(
                 parameter_raw
             )
-    data_sources_new = hub.tool.aws.guardduty.detector_utils.render_data_sources(
+    data_sources_new = hub.tool.aws.guardduty.detector.render_data_sources(
         detector_describe
     )
 
