@@ -15,7 +15,7 @@ async def update(
     compare_dict_result = False
     update_payload = {}
     if (finding_publishing_frequency is not None) and before["ret"].get(
-        "FindingPublishingFrequency"
+        "finding_publishing_frequency"
     ) != finding_publishing_frequency:
         update_payload["FindingPublishingFrequency"] = finding_publishing_frequency
     data_describe = before["ret"]
