@@ -75,6 +75,8 @@ def convert_raw_db_cluster_to_present(
             "DBSubnetGroup": "db_subnet_group_name",
             "TagList": "tags",
             "ScalingConfigurationInfo": "scaling_configuration",
+            "IAMDatabaseAuthenticationEnabled": "iam_database_authentication_enabled",
+            "Endpoint": "endpoint",
         }
     )
     resource_id = raw_resource.get("DBClusterIdentifier")
@@ -151,6 +153,7 @@ async def convert_raw_db_instance_to_present(
             "MonitoringRoleArn": "monitoring_role_arn",
             "PromotionTier": "promotion_tier",
             "Timezone": "timezone",
+            "PerformanceInsightsEnabled": "performance_insights_enabled",
             "PerformanceInsightsKMSKeyId": "performance_insights_kms_key_id",
             "PerformanceInsightsRetentionPeriod": "performance_insights_retention_period",
             "EnableCloudwatchLogsExports": "enable_cloudwatch_logs_exports",
