@@ -1,3 +1,4 @@
+"""Tool module for various conversion of Amazon S3 bucket resources."""
 import json
 from typing import Any
 from typing import Dict
@@ -6,12 +7,14 @@ from typing import Dict
 def convert_raw_bucket_notification_to_present(
     hub, raw_resource: Dict[str, Any], bucket_name: str
 ) -> Dict[str, Any]:
-    """
-    Convert the s3 bucket notification configurations response to a common format
+    """Convert the s3 bucket notification configurations response to a common format.
 
     Args:
-        raw_resource: Dictionary of s3 bucket notification configurations
-        bucket_name: Name of the bucket on which notification needs to be configured.
+        raw_resource(Dict[str, Any]):
+            Dictionary of s3 bucket notification configurations
+
+        bucket_name(str):
+            Name of the bucket on which notification needs to be configured.
 
     Returns:
         A dictionary of s3 bucket notification configurations
@@ -29,12 +32,14 @@ def convert_raw_bucket_notification_to_present(
 def convert_raw_bucket_logging_to_present(
     hub, ctx, raw_resource: Dict[str, Any], bucket_name: str
 ) -> Dict[str, Any]:
-    """
-    Convert the s3 bucket logging configurations response to a common format
+    """Convert the s3 bucket logging configurations response to a common format.
 
     Args:
-        raw_resource: Dictionary of s3 bucket logging configurations
-        bucket_name: Name of the bucket on which logging needs to be configured.
+        raw_resource(Dict[str, Any]):
+            Dictionary of s3 bucket logging configurations.
+
+        bucket_name(str):
+            Name of the bucket on which logging needs to be configured.
 
     Returns:
         A dictionary of s3 bucket logging configurations
@@ -54,11 +59,11 @@ def convert_raw_bucket_logging_to_present(
 async def convert_raw_s3_to_present(
     hub, ctx, idem_resource_name: str = None
 ) -> Dict[str, Any]:
-    """
-    Convert the s3 bucket configurations response to a common format
+    """Convert the s3 bucket configurations response to a common format.
 
     Args:
-        idem_resource_name: Name of the bucket.
+        idem_resource_name(str, Optional):
+            Name of the bucket.
 
     Returns:
         Dict[str, Any]
@@ -197,6 +202,7 @@ async def convert_raw_s3_to_present(
 def convert_raw_public_access_block_to_present(
     hub, bucket_name: str, public_access_block_configuration: Dict
 ) -> Dict[str, Any]:
+    """Util function to convert the s3 bucket public access block response to a common format."""
     translated_resource = {
         "name": f"{bucket_name}-public-access-block",
         "bucket": bucket_name,
@@ -211,13 +217,17 @@ def convert_raw_public_access_block_to_present(
 def convert_raw_bucket_policy_to_present(
     hub, raw_resource: Dict[str, Any], bucket: str, name: str
 ) -> Dict[str, Any]:
-    """
-    Util function to convert the s3 bucket policy response to a common format
+    """Util function to convert the s3 bucket policy response to a common format.
 
     Args:
-        hub: required for functions in hub
-        raw_resource: S3 bucket policy response
-        bucket: Name of the bucket on which policy needs to be configured.
+        raw_resource(Dict[str, Any]):
+            S3 bucket policy response.
+
+        bucket(str):
+            Name of the bucket on which policy needs to be configured.
+
+        name(str):
+            The name of the idem resource.
 
     Returns:
         A dictionary of s3 bucket notification configurations
@@ -236,12 +246,14 @@ def convert_raw_bucket_policy_to_present(
 def convert_raw_bucket_replication_to_present(
     hub, ctx, raw_resource: Dict[str, Any], bucket_name: str
 ) -> Dict[str, Any]:
-    """
-    Convert the s3 bucket replication configurations response to a common format
+    """Convert the s3 bucket replication configurations response to a common format.
 
     Args:
-        raw_resource: Dictionary of s3 bucket replication configurations
-        bucket_name: Name of the bucket on which replication needs to be configured.
+        raw_resource(Dict[str, Any]):
+            Dictionary of s3 bucket replication configurations.
+
+        bucket_name(str):
+            Name of the bucket on which replication needs to be configured.
 
     Returns:
         A dictionary of s3 bucket replication configurations
@@ -260,13 +272,14 @@ def convert_raw_bucket_replication_to_present(
 def convert_raw_acl_policy_to_present(
     hub, raw_resource: Dict[str, Any], bucket_name: str
 ) -> Dict[str, Any]:
-    """
-    Util function to convert the s3 bucket policy response to a common format
+    """Util function to convert the s3 bucket policy response to a common format.
 
     Args:
-        hub: required for functions in hub
-        raw_resource (Dict): S3 bucket policy response
-        bucket_name(str): Name of the bucket on which policy needs to be configured.
+        raw_resource(Dict):
+            S3 bucket policy response.
+
+        bucket_name(str):
+            Name of the bucket on which policy needs to be configured.
 
     Returns:
         A dictionary of s3 bucket notification configurations
