@@ -1,11 +1,8 @@
+"""Util functions for converting raw attributes to present form and vice versa."""
 import json
 from typing import Any
 from typing import Dict
 
-"""
-Util functions for converting raw attributes to present form and vice versa
-"""
-
 
 ATTRIBUTES_NAMES_RAW_TO_PRESENT = {
     "DelaySeconds": "delay_seconds",
@@ -47,17 +44,18 @@ PRESENT_ATTRIBUTES_TYPES = {
 def convert_raw_attributes_to_present(
     hub, raw_attributes: Dict[str, str]
 ) -> Dict[str, Any]:
-    """
-    Converts raw attributes to a dict of present values. The types of the values are also changed from string
-        to whatever the type of the attribute should be in the present SLS form
+    """Converts raw attributes to a dict of present values.
+
+    The types of the values are also changed from string to whatever the type of the attribute should be in the present
+    SLS form.
 
     Args:
-        hub: required for functions in hub
-        raw_attributes(Dict): the attributes as directly returned by the boto3 API
+        raw_attributes(Dict):
+            The attributes as directly returned by the boto3 API
 
-    Returns: a dict of the attributes converted to present form
+    Returns:
+        a dict of the attributes converted to present form
     """
-
     present_attributes = {}
 
     for (
@@ -98,34 +96,56 @@ def convert_present_attributes_to_raw(
     deduplication_scope: str,
     fifo_throughput_limit: str,
 ) -> Dict[str, str]:
-    """
-    Converts present attributes to a dict of raw string values
+    """Converts present attributes to a dict of raw string values.
 
     Args:
-        hub: required for functions in hub
-        delay_seconds(int): The length of time, in seconds, for which the delivery of all messages in the queue is delayed
-        maximum_message_size(int): The limit of how many bytes a message can contain before Amazon SQS rejects it
-        message_retention_period(int): The length of time, in seconds, for which Amazon SQS retains a message
-        policy(Dict): The queue's policy
-        receive_message_wait_time_seconds(int): The length of time, in seconds, for which a ReceiveMessage
-            action waits for a message to arrive
-        redrive_policy(Dict): The dict that includes the parameters for the dead-letter queue functionality
-            of the source queue
-        visibility_timeout(int): The visibility timeout for the queue, in seconds
-        kms_master_key_id(str): The ID of an Amazon Web Services managed customer master key (CMK) for
-            Amazon SQS or a custom CMK
-        kms_data_key_reuse_period_seconds(int): The length of time, in seconds, for which Amazon SQS can
-            reuse a data key to encrypt or decrypt messages before calling KMS again
-        sqs_managed_sse_enabled(bool, optional): enables server-side queue encryption using SQS owned encryption keys.
-            Only one server-side encryption option is supported per queue.
-        fifo_queue(bool): Designates a queue as FIFO
-        content_based_deduplication(bool): Enables content-based deduplication
-        deduplication_scope(str): Specifies whether message deduplication occurs at the message group or queue level
-        fifo_throughput_limit(str): Specifies whether the FIFO queue throughput quota applies to the entire
+        delay_seconds(int):
+            The length of time, in seconds, for which the delivery of all messages in the queue is delayed
 
-    Returns: a dict of the attributes converted to raw form
+        maximum_message_size(int):
+            The limit of how many bytes a message can contain before Amazon SQS rejects it
+
+        message_retention_period(int):
+            The length of time, in seconds, for which Amazon SQS retains a message
+
+        policy(Dict):
+            The queue's policy
+
+        receive_message_wait_time_seconds(int):
+            The length of time, in seconds, for which a ReceiveMessage action waits for a message to arrive
+
+        redrive_policy(Dict):
+            The dict that includes the parameters for the dead-letter queue functionality of the source queue
+
+        visibility_timeout(int):
+            The visibility timeout for the queue, in seconds
+
+        kms_master_key_id(str):
+            The ID of an Amazon Web Services managed customer master key (CMK) for Amazon SQS or a custom CMK
+
+        kms_data_key_reuse_period_seconds(int):
+            The length of time, in seconds, for which Amazon SQS can reuse a data key to encrypt or decrypt messages
+            before calling KMS again
+
+        sqs_managed_sse_enabled(bool, Optional):
+            enables server-side queue encryption using SQS owned encryption keys. Only one server-side encryption option
+            is supported per queue.
+
+        fifo_queue(bool):
+            Designates a queue as FIFO
+
+        content_based_deduplication(bool):
+            Enables content-based deduplication
+
+        deduplication_scope(str):
+            Specifies whether message deduplication occurs at the message group or queue level
+
+        fifo_throughput_limit(str):
+            Specifies whether the FIFO queue throughput quota applies to the entire
+
+    Returns:
+        a dict of the attributes converted to raw form
     """
-
     all_attributes = {
         "DelaySeconds": delay_seconds,
         "MaximumMessageSize": maximum_message_size,
