@@ -145,7 +145,7 @@ def convert_raw_ip_set_to_present(
         ctx:
             A dict with the keys/values for the execution of the Idem run located in
             `hub.idem.RUNS[ctx['run_name']]`.
-        scope (string) --
+        scope (str) --
             Specifies whether this is for an Amazon CloudFront distribution or for a regional
             application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway
             REST API, or an AppSync GraphQL API.
