@@ -1,4 +1,7 @@
+import copy
+
 import boto3.session
+import dict_tools.data
 
 
 def __init__(hub):
@@ -16,10 +19,18 @@ def get(hub, botocore_session=None) -> boto3.session.Session:
     return hub.tool.boto3.SESSION
 
 
-def kwargs(hub, ctx):
+async def kwargs(hub, ctx):
     """
     Return the kwargs for a session object from ctx.acct in a consistent way
     """
+    new_profile = dict_tools.data.NamespaceDict()
+    # Apply modifications to the profile before using it
+    await hub.tool.aws.acct.init.modify(
+        hub.OPT.idem.get("acct_profile") if hub.OPT.get("idem") else None,
+        copy.deepcopy(ctx.acct),
+        new_profile,
+    )
+    ctx.acct = new_profile
     return dict(
         region_name=hub.tool.boto3.region.get(ctx),
         api_version=ctx.acct.get("api_version"),
@@ -29,4 +40,5 @@ def kwargs(hub, ctx):
         aws_secret_access_key=ctx.acct.get("aws_secret_access_key"),
         aws_session_token=ctx.acct.get("aws_session_token"),
         verify=ctx.acct.get("verify"),
+        config=ctx.acct.get("config"),
     )
